I was reminded about 64bit patches.

o rename three patches to 'update-patches' naming conventions
o add 64bit patches
o add other tidbits from my
   opencm://opencm.org/everyone/todd@fries.net/home/merge-candidate
  branch
This commit is contained in:
todd 2002-08-27 17:43:14 +00:00
parent 0dd4b72c32
commit ee03b19c7a
50 changed files with 2483 additions and 53 deletions

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/Makefile.in.orig Mon Aug 5 16:03:06 2002
+++ base/Makefile.in Tue Aug 27 12:25:26 2002
@@ -104,8 +104,6 @@ mandir = $(if $(sharemandir),$(sharemand
FLAGS_TO_PASS = \
AR='$(AR)' \
CC='$(CC)' \
- CFLAGS='$(CFLAGS)' \
- LDFLAGS='$(LDFLAGS)' \
LIBPROGS='$(LIBPROGS)' \
LIBS='$(LIBS)' \
MAKE='$(MAKE)' \

View File

@ -1,17 +1,22 @@
$OpenBSD: patch-base_aclocal_m4,v 1.1.1.1 2002/08/27 16:46:09 todd Exp $
--- base/aclocal.m4.orig Wed Jul 31 05:29:31 2002
+++ base/aclocal.m4 Wed Jul 31 05:29:03 2002
@@ -1,12 +1,6 @@
$OpenBSD: patch-base_aclocal_m4,v 1.2 2002/08/27 17:43:14 todd Exp $
--- base/aclocal.m4.orig Tue Jul 30 10:19:03 2002
+++ base/aclocal.m4 Tue Aug 27 12:25:26 2002
@@ -1,10 +1,14 @@
AC_DEFUN([AC_AUTOCONFIG_GC], [
AC_MSG_CHECKING([if autoconf has been run for gc6.0])
- if test -r gc6.0/configure; then
- AC_MSG_RESULT([yes])
- else
+ if test -d gc6.0; then
+ if test -r gc6.0/configure; then
+ AC_MSG_RESULT([yes])
+ else
+ (cd gc6.0; autoconf)
+ AC_MSG_RESULT([built])
+ fi
else
- (cd gc6.0; autoconf)
- AC_MSG_RESULT([built])
- fi
- ])
+ AC_MSG_RESULT([yes])
+ echo "no - using external gc6.0"
fi
])
])
dnl The check for libtermcap/libcurses is a HUGE mess. First, the headers

File diff suppressed because it is too large Load Diff

View File

@ -1,6 +1,6 @@
--- base/doc/manual/cmd-ref.texi.orig Wed Aug 14 17:50:36 2002
+++ base/doc/manual/cmd-ref.texi Wed Aug 14 17:50:46 2002
@@ -21,7 +21,7 @@
--- base/doc/manual/cmd-ref.texi.orig Wed Jul 17 12:10:30 2002
+++ base/doc/manual/cmd-ref.texi Tue Aug 27 12:36:18 2002
@@ -21,7 +21,7 @@ specified @cmdarg{member} must either be
have write access on the group in order to add members to it.
@item

View File

@ -0,0 +1,11 @@
--- base/doc/manual/cmd-ref.texi.orig Wed Aug 14 17:50:36 2002
+++ base/doc/manual/cmd-ref.texi Wed Aug 14 17:50:46 2002
@@ -21,7 +21,7 @@
have write access on the group in order to add members to it.
@item
-@command{add user} @cmdarg{cert-file} @cmdarg{('r'|'w'|'rw')}
+@command{adduser} @cmdarg{cert-file} @cmdarg{('r'|'w'|'rw')}
Registers a user on a repository by copying the new user's certificate
file (whose path is specified as @cmdarg{cert-file}) to the repository

View File

@ -1,6 +1,7 @@
--- base/doc/opencm.texi.orig Wed Aug 14 17:50:54 2002
+++ base/doc/opencm.texi Wed Aug 14 17:51:03 2002
@@ -855,7 +855,7 @@
$OpenBSD: patch-base_doc_opencm_texi,v 1.2 2002/08/27 17:43:14 todd Exp $
--- base/doc/opencm.texi.orig Mon Jul 29 22:48:38 2002
+++ base/doc/opencm.texi Tue Aug 27 12:25:26 2002
@@ -855,7 +855,7 @@ reconstruct your certificate if this hap
When the administrator receives the certificate, they can create
authorize this user by typing:
@example
@ -9,7 +10,7 @@
@end example
The argument @kbd{jack.pem} is the path to the certificate file for the
@@ -1592,7 +1592,7 @@
@@ -1592,7 +1592,7 @@ uploaded to repository until the @code{c
@cmdarg{member} to the existing @cmdarg{group}.
@item

View File

@ -0,0 +1,10 @@
$OpenBSD: patch-base_src_client_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/client/Makefile.in.orig Mon Jul 8 16:30:33 2002
+++ base/src/client/Makefile.in Tue Aug 27 12:25:26 2002
@@ -41,5 +41,5 @@
default: all
all install uninstall clean:
- make -C ../ $@
+ ${MAKE} -C ../ $@

View File

@ -0,0 +1,21 @@
$OpenBSD: patch-base_src_client_WsEntity_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/client/WsEntity.h.orig Mon Aug 5 20:06:46 2002
+++ base/src/client/WsEntity.h Tue Aug 27 12:25:26 2002
@@ -181,7 +181,7 @@ struct WsEntity {
unsigned flags;
const char *cur_fsName;
unsigned char cur_entityType;
- unsigned long cur_entityPerms;
+ u_int32_t cur_entityPerms;
const char *cur_mergeParent;
const char *cur_mergeParentChange;
@@ -190,7 +190,7 @@ struct WsEntity {
believe them unless you have recently recomputed them via
wsentity_RecomputeStatus(). */
const char *lk_contentTrueName;
- unsigned long lk_length;
+ u_int32_t lk_length;
/* Last known modification time. This is used to avoid running the
expensive SHA-1 check in wsentity_RecomputeStatus(). If the mod

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_client_browse_Browse_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/client/browse/Browse.c.orig Mon Jul 22 02:02:51 2002
+++ base/src/client/browse/Browse.c Tue Aug 27 12:25:26 2002
@@ -101,7 +101,7 @@ uri_encode(const char *s)
*to++ = *from;
}
else {
- unsigned long c = ((unsigned)*from) & 0xffu;
+ u_int32_t c = ((unsigned)*from) & 0xffu;
*to++ = '%';
*to++ = hex[c >> 4];

View File

@ -1,6 +1,6 @@
--- base/src/client/command.c.orig Wed Aug 14 17:54:02 2002
+++ base/src/client/command.c Wed Aug 14 17:54:18 2002
@@ -154,7 +154,7 @@
--- base/src/client/command.c.orig Mon Aug 5 16:03:03 2002
+++ base/src/client/command.c Tue Aug 27 12:30:49 2002
@@ -154,7 +154,7 @@ struct command top_cmds[] = {
{ "add", opencm_add_file, 1, CF_OPTARGS|CF_NOCONNECT|CF_WSINIT, 0,
"add.help" },
{ "adduser", opencm_add_user, 2, CF_ADMIN, 0,

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_client_opencm_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/client/opencm.c.orig Mon Aug 5 23:58:07 2002
+++ base/src/client/opencm.c Tue Aug 27 12:25:26 2002
@@ -334,7 +334,7 @@ client_doDupBranchMut(Repository *r, Res
unsigned mutFlags)
{
Mutable *dupM = NULL;
- unsigned long version = 0ul;
+ u_int32_t version = 0ul;
/* By default, we want to copy the ACLs when we duplicate the mutable.
* The --private command line option overrides this and sets the ACLs of

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_ChannelSSL_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/ChannelSSL.c.orig Sun Aug 4 11:51:37 2002
+++ base/src/common/ChannelSSL.c Tue Aug 27 12:25:27 2002
@@ -117,7 +117,7 @@ chan_alisten_ssl(ChannelCompletionFn fn,
}
static void
-report_ssl_error(int level, unsigned long errcode)
+report_ssl_error(int level, u_int32_t errcode)
{
if(errcode == 0)
report(level, "No OpenSSL error reported (!)\n");

View File

@ -0,0 +1,14 @@
$OpenBSD: patch-base_src_common_EntityCache_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/EntityCache.c.orig Mon Jul 29 22:48:38 2002
+++ base/src/common/EntityCache.c Tue Aug 27 12:25:27 2002
@@ -61,8 +61,8 @@ struct EcacheNode {
};
struct EntityCache {
- unsigned long sz;
- unsigned long max;
+ u_int32_t sz;
+ u_int32_t max;
rbtree *tree;
EcacheNode *oldest; /* pointer to oldest */

View File

@ -0,0 +1,21 @@
$OpenBSD: patch-base_src_common_Entity_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/Entity.h.orig Thu Jul 18 20:30:51 2002
+++ base/src/common/Entity.h Tue Aug 27 12:25:27 2002
@@ -58,7 +58,7 @@ struct Entity {
*/
const char *contentTrueName;
- unsigned long length; /* length of object */
+ u_int32_t length; /* length of object */
/* Miscellaneous per-entity meta information. Much of this is
* contained in the Change record, but it isn't accessable to the
@@ -72,7 +72,7 @@ struct Entity {
unsigned char entityType; /* type of content */
- unsigned long entityPerms; /* permissions flags */
+ u_int32_t entityPerms; /* permissions flags */
const char *parent; /* preceding Entity (on same Branch) */
const char *mergeParent; /* merged, preceding Entity (if any) */

View File

@ -0,0 +1,10 @@
$OpenBSD: patch-base_src_common_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/Makefile.in.orig Mon Jul 8 16:30:46 2002
+++ base/src/common/Makefile.in Tue Aug 27 12:25:27 2002
@@ -41,5 +41,5 @@
default: all
all install uninstall clean:
- make -C ../ $@
+ ${MAKE} -C ../ $@

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_ObDict_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/ObDict.h.orig Wed Jul 17 23:27:55 2002
+++ base/src/common/ObDict.h Tue Aug 27 12:25:27 2002
@@ -44,7 +44,7 @@
typedef struct ObDictEntry ObDictEntry;
struct ObDictEntry {
const char *trueName; /* of the object */
- unsigned long tnHash; /* hash of the truename for quick compare */
+ u_int32_t tnHash; /* hash of the truename for quick compare */
unsigned w; /* aux word */
void *value;

View File

@ -0,0 +1,14 @@
$OpenBSD: patch-base_src_common_Revision_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/Revision.c.orig Mon Jul 29 22:48:34 2002
+++ base/src/common/Revision.c Tue Aug 27 12:25:27 2002
@@ -47,8 +47,8 @@ revision_show(const void *vp)
xprintf("mutURI: %s\n", r->mutURI);
xprintf("Seq Num: 0x%08x%08x\n",
- (unsigned long) (r->seq_number >> 32),
- (unsigned long) (r->seq_number));
+ (u_int32_t) (r->seq_number >> 32),
+ (u_int32_t) (r->seq_number));
xprintf("ReviseTime: %s\n", r->reviseTime);
xprintf("Revisor: %s\n", r->revisor);
xprintf("NewObject: %s\n", r->newObject);

View File

@ -0,0 +1,297 @@
$OpenBSD: patch-base_src_common_SDR_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/SDR.h.orig Mon Jul 22 02:02:49 2002
+++ base/src/common/SDR.h Tue Aug 27 12:25:27 2002
@@ -104,17 +104,17 @@ void sdr_w_u16(const char *ele
unsigned short sdr_r_u16(const char *elem, SDR_stream *);
void sdr_w_u32(const char *elem, SDR_stream *,
- unsigned long);
-unsigned long sdr_r_u32(const char *elem, SDR_stream *);
+ u_int32_t);
+u_int32_t sdr_r_u32(const char *elem, SDR_stream *);
void sdr_w_u64(const char *elem, SDR_stream *,
oc_uint64_t);
oc_uint64_t sdr_r_u64(const char *elem, SDR_stream *);
void sdr_w_bytes(const char *elem, SDR_stream *,
- unsigned long len, const void *);
+ u_int32_t len, const void *);
void * sdr_r_bytes(const char *elem, SDR_stream *,
- unsigned long len);
+ u_int32_t len);
void sdr_w_buffer(const char *elem, SDR_stream *, const Buffer*);
Buffer * sdr_r_buffer(const char *elem, SDR_stream *, ocmoff_t len);

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_Serializable_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/Serializable.c.orig Mon Jul 29 22:48:29 2002
+++ base/src/common/Serializable.c Tue Aug 27 12:25:27 2002
@@ -72,7 +72,7 @@ SerialType *serTypes[TY_ntypes] = {
#include "OBTYPES.def"
SerialType *
-ser_find_type(unsigned long t)
+ser_find_type(u_int32_t t)
{
unsigned u;

View File

@ -0,0 +1,34 @@
$OpenBSD: patch-base_src_common_Serializable_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/Serializable.h.orig Mon Jul 29 22:48:35 2002
+++ base/src/common/Serializable.h Tue Aug 27 12:25:27 2002
@@ -56,8 +56,8 @@ enum {
typedef struct DeserializeInfo DeserializeInfo;
struct DeserializeInfo {
struct SerialType *st;
- unsigned long tyConst; /* type constant as serialized */
- unsigned long ver; /* version number as serialized */
+ u_int32_t tyConst; /* type constant as serialized */
+ u_int32_t ver; /* version number as serialized */
};
#define OBTYPE(nm,prefix,abbrev,ver) \
@@ -76,8 +76,8 @@ struct DeserializeInfo {
canonicalize the internal representation before displaying the
object. */
struct SerialType {
- unsigned long typ; /* type constant for this object */
- unsigned long ver; /* version constant for this object */
+ u_int32_t typ; /* type constant for this object */
+ u_int32_t ver; /* version constant for this object */
const char * tyName; /* used in texty formats */
const char * prefix; /* used as first part of truename */
void * (*deserialize) (const DeserializeInfo *, SDR_stream *);
@@ -99,7 +99,7 @@ struct Serializable {
#define serTrueName ser.ser_trueName
#define serPrefix ser.ser_type->prefix
-SerialType *ser_find_type(unsigned long ty);
+SerialType *ser_find_type(u_int32_t ty);
void ser_init(void);
const char *ser_getTrueName(const void *);

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_ServerRequest_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/ServerRequest.h.orig Tue Jul 16 21:49:02 2002
+++ base/src/common/ServerRequest.h Tue Aug 27 12:25:27 2002
@@ -41,7 +41,7 @@
* POSSIBILITY OF SUCH DAMAGE.
*/
-typedef unsigned long reqlen_t;
+typedef u_int32_t reqlen_t;
typedef struct Request {
Serializable ser;

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_TrueName_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/TrueName.h.orig Wed Jul 17 23:27:56 2002
+++ base/src/common/TrueName.h Tue Aug 27 12:25:27 2002
@@ -49,7 +49,7 @@ const char *truename_NewName(void);
/* Generate an integer hash of the trueName suitable for use in hash
tables */
-typedef unsigned long tnhash_t;
+typedef u_int32_t tnhash_t;
tnhash_t truename_hash(const char *trueName);

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_WireException_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/WireException.h.orig Mon Jul 8 16:31:00 2002
+++ base/src/common/WireException.h Tue Aug 27 12:25:27 2002
@@ -46,7 +46,7 @@ typedef struct WireException {
const char *name; /* exception name */
const char *fname; /* file where thrown (string) */
- unsigned long line; /* line number where thrown */
+ u_int32_t line; /* line number where thrown */
const char *str; /* explanation string */
} WireException;

View File

@ -0,0 +1,20 @@
$OpenBSD: patch-base_src_common_encode_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/encode.c.orig Mon Jul 8 16:31:06 2002
+++ base/src/common/encode.c Tue Aug 27 12:25:27 2002
@@ -127,12 +127,12 @@ b64_encode(const void *vp, unsigned int
char *pBuf = outbuf;
while (len) {
- unsigned long take = min(len, 3);
- unsigned long value = 0;
- unsigned long outlen = (take * 8 + 5) / 6;
+ u_int32_t take = min(len, 3);
+ u_int32_t value = 0;
+ u_int32_t outlen = (take * 8 + 5) / 6;
unsigned i;
- assert(sizeof(unsigned long) == 4);
+ assert(sizeof(u_int32_t) == 4);
if (take == 3) {
value = cp[2];

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_except_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/except.c.orig Mon Jul 8 16:31:09 2002
+++ base/src/common/except.c Tue Aug 27 12:25:27 2002
@@ -73,7 +73,7 @@ DEFEXCEPTION(ExUnspecified, "Unspecified
excpt_unwind *exit_unwind_list = 0;
void
-_throw(catch_t *_cb, const char *fname, unsigned long line,
+_throw(catch_t *_cb, const char *fname, u_int32_t line,
Exception ex, const char *s)
{
_curCatch = _cb;

View File

@ -0,0 +1,21 @@
$OpenBSD: patch-base_src_common_except_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/except.h.orig Thu Jul 18 20:30:57 2002
+++ base/src/common/except.h Tue Aug 27 12:25:27 2002
@@ -57,7 +57,7 @@ struct catch {
jmp_buf jbuf; /* saved catch environment */
Exception excpt; /* thrown exception value */
const char *fname; /* file where thrown (string) */
- unsigned long line; /* line number where thrown */
+ u_int32_t line; /* line number where thrown */
const char *str; /* explanation string */
catch_t *up; /* next (upward) catch block */
OC_bool caught; /* whether this exception was handled */
@@ -107,7 +107,7 @@ extern catch_t *_curCatch;
debugger. */
extern void _throw(catch_t *,
const char *fname,
- unsigned long line,
+ u_int32_t line,
Exception,
const char *s) __attribute__ ((__noreturn__));

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_common_rbtree_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/rbtree.c.orig Mon Aug 5 21:21:38 2002
+++ base/src/common/rbtree.c Tue Aug 27 12:25:27 2002
@@ -99,7 +99,7 @@ rbtree_s_cmpkey(const rbnode *rn1, const
rbnode *
-rbnode_create(const void *kvp, unsigned long kw, const void *data)
+rbnode_create(const void *kvp, u_int32_t kw, const void *data)
{
rbnode *rbn = GC_MALLOC(sizeof(rbnode));
rbn->left = TREE_NIL;

View File

@ -0,0 +1,21 @@
$OpenBSD: patch-base_src_common_rbtree_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/rbtree.h.orig Mon Jul 29 22:48:43 2002
+++ base/src/common/rbtree.h Tue Aug 27 12:25:27 2002
@@ -47,7 +47,7 @@
typedef struct rbkey rbkey;
struct rbkey {
const void *vp;
- unsigned long w;
+ u_int32_t w;
};
/* The rbnode and rbkey structures are exposed because it is sometimes
@@ -103,7 +103,7 @@ int rbtree_compare_node_to_key(rbtree*,
int rbtree_compare_nodes(rbtree*, rbnode *, rbnode *);
/* For situations where the rbnode itself is sufficient: */
-rbnode *rbnode_create(const void *kvp, unsigned long kw, const void *data);
+rbnode *rbnode_create(const void *kvp, u_int32_t kw, const void *data);
#ifndef NDEBUG
/* tree_validate() -- check the subtree of ROOT rooted at NODE for

View File

@ -0,0 +1,47 @@
$OpenBSD: patch-base_src_common_sxdelta_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/common/sxdelta.c.orig Mon Aug 5 16:03:05 2002
+++ base/src/common/sxdelta.c Tue Aug 27 12:25:27 2002
@@ -133,7 +133,7 @@
something using limits.h to choose the proper value. */
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
-typedef unsigned long uint32_t;
+typedef u_int32_t uint32_t;
#endif
typedef struct hashpos_t {
@@ -597,9 +597,9 @@ emit_finish(sxdelta_t *xd)
#define HT_SHA1 0
typedef struct xdirent_t {
- unsigned long insOffset; /* of start of insert pool list */
- unsigned long cmdOffset; /* of start of CMD list */
- unsigned long cmdLen; /* of CMD list */
+ u_int32_t insOffset; /* of start of insert pool list */
+ u_int32_t cmdOffset; /* of start of CMD list */
+ u_int32_t cmdLen; /* of CMD list */
unsigned const char *name; /* entry name */
} xdirent_t;
@@ -608,9 +608,9 @@ typedef struct XDeltaArchive_t {
unsigned short version; /* currently 1 */
unsigned short flags; /* currently 0 */
- unsigned long nDirent; /* number of entries */
- unsigned long maxDirent; /* allocated dir space */
- unsigned long nContent; /* number of stored deltas */
+ u_int32_t nDirent; /* number of entries */
+ u_int32_t maxDirent; /* allocated dir space */
+ u_int32_t nContent; /* number of stored deltas */
struct xdirent_t *dir;
Buffer *content; /* sequence of serialized xdeltas */
@@ -694,7 +694,7 @@ xda_rewriteWith(XDeltaArchive_t *xda, sx
unsigned u;
ocmoff_t contentLen = buffer_length(xda->content);
- unsigned long newLen = contentLen;
+ u_int32_t newLen = contentLen;
newLen += stream_length(xd->ins);
newLen += stream_length(xd->cmd);
xda->nContent = newLen;

View File

@ -0,0 +1,66 @@
$OpenBSD: patch-base_src_common_util_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/help/add.help.orig Thu Aug 15 12:56:03 2002
+++ base/src/help/add.help Thu Aug 15 12:56:19 2002
@@ -43,5 +43,5 @@
$OpenBSD: patch-base_src_help_add_help,v 1.2 2002/08/27 17:43:14 todd Exp $
--- base/src/help/add.help.orig Mon Jul 29 22:48:36 2002
+++ base/src/help/add.help Tue Aug 27 12:25:27 2002
@@ -43,5 +43,5 @@ Add one or more files to an existing bra
User's workspace specifies the current (working) branch into which
the specified files will go. Permanent changes don't take effect until

View File

@ -1,6 +1,6 @@
--- base/src/help/bind.help.orig Wed Aug 14 17:51:38 2002
+++ base/src/help/bind.help Wed Aug 14 17:51:48 2002
@@ -43,5 +43,5 @@
--- base/src/help/bind.help.orig Sun Aug 4 11:51:35 2002
+++ base/src/help/bind.help Tue Aug 27 12:30:49 2002
@@ -43,5 +43,5 @@ Adds an entry in the user's directory th
In most cases @i{value} is the truename of some archived object and
@i{key} is the more user-friendly name associated with that object.

View File

@ -0,0 +1,9 @@
$OpenBSD: patch-base_src_help_create-repository_help,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/help/create-repository.help.orig Mon Jul 8 16:31:55 2002
+++ base/src/help/create-repository.help Tue Aug 27 12:25:27 2002
@@ -44,4 +44,4 @@ repository, via @i{local-path}. The fir
is specified via @i{admin-user}, which must be the local path to a PEM file
representing the admin user's X.509 certificate.
-See also: @b{add user}, @b{create user}
+See also: @b{adduser}, @b{create user}

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_help_create-user_help,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/help/create-user.help.orig Mon Jul 8 16:31:56 2002
+++ base/src/help/create-user.help Tue Aug 27 12:25:27 2002
@@ -47,7 +47,7 @@ private key and certificate files. The
NOTE:
- The output cert file is used for the 'add user' command.
+ The output cert file is used for the 'adduser' command.
Safeguard all private keys!

View File

@ -1,8 +0,0 @@
--- base/src/help/create-repository.help.orig Wed Aug 14 17:52:02 2002
+++ base/src/help/create-repository.help Wed Aug 14 17:52:15 2002
@@ -44,4 +44,4 @@
is specified via @i{admin-user}, which must be the local path to a PEM file
representing the admin user's X.509 certificate.
-See also: @b{add user}, @b{create user}
+See also: @b{adduser}, @b{create user}

View File

@ -1,11 +0,0 @@
--- base/src/help/create-user.help.orig Wed Aug 14 17:52:40 2002
+++ base/src/help/create-user.help Wed Aug 14 17:52:48 2002
@@ -47,7 +47,7 @@
NOTE:
- The output cert file is used for the 'add user' command.
+ The output cert file is used for the 'adduser' command.
Safeguard all private keys!

View File

@ -1,6 +1,7 @@
--- base/src/help/gadd.help.orig Wed Aug 14 17:51:19 2002
+++ base/src/help/gadd.help Wed Aug 14 17:51:26 2002
@@ -43,4 +43,4 @@
$OpenBSD: patch-base_src_help_gadd_help,v 1.2 2002/08/27 17:43:14 todd Exp $
--- base/src/help/gadd.help.orig Mon Jul 29 22:48:34 2002
+++ base/src/help/gadd.help Tue Aug 27 12:25:27 2002
@@ -43,4 +43,4 @@ Add @i{member} to the specified (existin
@i{member} must either be a user or group and must be defined in executing
user's directory.

View File

@ -1,5 +1,6 @@
--- base/src/help/opt-obscure.help.orig Thu Aug 15 13:23:06 2002
+++ base/src/help/opt-obscure.help Thu Aug 15 13:23:38 2002
$OpenBSD: patch-base_src_help_opt-obscure_help,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/help/opt-obscure.help.orig Thu Jul 18 20:30:51 2002
+++ base/src/help/opt-obscure.help Tue Aug 27 12:25:27 2002
@@ -39,7 +39,7 @@
@C
@i{Option} @i{Description}

View File

@ -1,6 +1,6 @@
--- base/src/help/revert.help.orig Thu Aug 15 02:27:03 2002
+++ base/src/help/revert.help Thu Aug 15 02:27:48 2002
@@ -43,7 +43,7 @@
--- base/src/help/revert.help.orig Sun Aug 4 11:51:40 2002
+++ base/src/help/revert.help Tue Aug 27 12:30:49 2002
@@ -43,7 +43,7 @@ Removes all modifications to a user's Wo
the last @b{commit}.
If you only want to revert a single file, or a group of files, delete

View File

@ -0,0 +1,10 @@
$OpenBSD: patch-base_src_libdiff_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/libdiff/Makefile.in.orig Mon Aug 5 18:11:24 2002
+++ base/src/libdiff/Makefile.in Tue Aug 27 12:25:27 2002
@@ -41,5 +41,5 @@
default: all
all install uninstall clean:
- make -C ../ $@
+ ${MAKE} -C ../ $@

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_opencm_h,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/opencm.h.orig Mon Aug 5 16:03:07 2002
+++ base/src/opencm.h Tue Aug 27 12:25:27 2002
@@ -110,7 +110,7 @@ typedef struct Repository Repository;
typedef struct command command;
#if SIZEOF_UNSIGNED_LONG_LONG == 8
-typedef unsigned long long oc_uint64_t;
+typedef u_int32_t long oc_uint64_t;
#elif SIZEOF___UINT64 == 8
typedef __uint64 oc_uint64_t;
#error "OpenCM requires a 64-bit unsigned type."

View File

@ -0,0 +1,10 @@
$OpenBSD: patch-base_src_repos_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/repos/Makefile.in.orig Mon Jul 8 16:32:36 2002
+++ base/src/repos/Makefile.in Tue Aug 27 12:25:27 2002
@@ -41,5 +41,5 @@
default: all
all install uninstall clean:
- make -C ../ $@
+ ${MAKE} -C ../ $@

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_repos_fs_FSRepos_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/repos/fs/FSRepos.c.orig Mon Aug 5 20:06:47 2002
+++ base/src/repos/fs/FSRepos.c Tue Aug 27 12:25:27 2002
@@ -1005,7 +1005,7 @@ fsrepos_GetMutable(Repository *r, const
}
static Mutable *
-fsrepos_ReviseMutable(Repository *r, const char *mURI, unsigned long
+fsrepos_ReviseMutable(Repository *r, const char *mURI, u_int32_t
long curTopRev, void *s)
{
Mutable *m = repos_GetMutable(r, mURI);

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_repos_net_NetRepository_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/repos/net/NetRepository.c.orig Mon Jul 22 02:02:48 2002
+++ base/src/repos/net/NetRepository.c Tue Aug 27 12:25:27 2002
@@ -41,7 +41,7 @@
#include <opencm.h>
#include <repos/opencmrepos.h>
-static unsigned long request_id = 0;
+static u_int32_t request_id = 0;
#define make_request(x) do_make_request(OP_##x)
static Request *

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_src_server_DoRequest_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/server/DoRequest.c.orig Mon Jul 22 02:02:50 2002
+++ base/src/server/DoRequest.c Tue Aug 27 12:25:27 2002
@@ -189,7 +189,7 @@ svr_DoRequest(Channel *c, Request *req)
Reply *reply;
OC_bool shouldQuit = FALSE;
- static unsigned long nRequests = 0;
+ static u_int32_t nRequests = 0;
SDR_stream *reply_strm;

View File

@ -0,0 +1,10 @@
$OpenBSD: patch-base_src_server_Makefile_in,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/src/server/Makefile.in.orig Mon Jul 8 16:33:19 2002
+++ base/src/server/Makefile.in Tue Aug 27 12:25:27 2002
@@ -41,5 +41,5 @@
default: all
all install uninstall clean:
- make -C ../ $@
+ ${MAKE} -C ../ $@

View File

@ -0,0 +1,92 @@
$OpenBSD: patch-base_tools_cvsconvert_py,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/tools/cvsconvert.py.orig Mon Jul 29 22:48:41 2002
+++ base/tools/cvsconvert.py Tue Aug 27 12:25:27 2002
@@ -12,9 +12,9 @@ files = []
versions = []
commits = {}
-scratch_dir = "/tmp/scratchme.$$"
+scratch_dir = "$sd/workspace"
co_scratchfile = "%s.%d" % ("/tmp/cvscvt-coscratch", os.getpid())
-msg_scratchfile = "/tmp/cvscvt-msgscratch.$$"
+msg_scratchfile = "$sd/cvscvt-msgscratch.$$"
startup_dir = os.getcwd()
verbose = 0
@@ -202,6 +202,9 @@ class CvtSink:
# a branch was created and the file was immediately deleted on the
# branch.
v.operation = "I"
+ elif (v.state == "dead" and brstate[br] == "dead"):
+ # I dont know why this happened, but it exists in OpenBSD cvs.
+ v.operation = "D"
else:
raise "%s:%s: Unknown object state transition (%s -> %s)!" % (self.rcsname, v.revision, brstate[br], v.state)
@@ -554,7 +557,7 @@ class AppGui(Frame):
if len(adds) > 0:
avec = adds
while len(avec) > 0:
- self.text.insert(END, "${OPENCM} --flush-io -C %s add" % scratch_dir, "CMD")
+ self.text.insert(END, "cd %s && ${OPENCM} --flush-io add" % scratch_dir, "CMD")
map (lambda x, self=self: self.text.insert(END, " '%s'" % x.opencmname, "INPUT"), avec[0:10])
self.text.insert(END, "\n", "CMD")
self.text.insert(END, "checkstatus $? \"add failed\"\n", "CMD")
@@ -563,7 +566,7 @@ class AppGui(Frame):
if len(deletes) > 0:
dvec = deletes
while len(dvec) > 0:
- self.text.insert(END, "${OPENCM} --flush-io -C %s rm" % scratch_dir, "CMD")
+ self.text.insert(END, "cd %s && ${OPENCM} --flush-io rm" % scratch_dir, "CMD")
map (lambda x, self=self: self.text.insert(END, " '%s'" % x.opencmname, "INPUT"), dvec[0:10])
self.text.insert(END, "\n", "CMD")
self.text.insert(END, "checkstatus $? \"remove failed\"\n", "CMD")
@@ -578,7 +581,7 @@ class AppGui(Frame):
# Note: Following activity is illegal in 17 states.
avec = active
while len(avec) > 0:
- self.text.insert(END, "${OPENCM} --flush-io -C %s --force-hash status" % scratch_dir, "CMD")
+ self.text.insert(END, "cd %s && ${OPENCM} --flush-io --force-hash status" % scratch_dir, "CMD")
map (lambda x, self=self: self.text.insert(END, " %s" % x.opencmname, "INPUT"), avec[0:10])
self.text.insert(END, "\n", "CMD")
self.text.insert(END, "checkstatus $? \"status check failed\"\n", "CMD")
@@ -593,7 +596,7 @@ class AppGui(Frame):
# re_squote.sub("'\"'\"'", cmtmsg))
- self.text.insert(END, "${OPENCM} --flush-io -C %s commit --messagefile %s\n" %
+ self.text.insert(END, "cd %s && ${OPENCM} --flush-io commit --messagefile %s\n" %
(scratch_dir, msg_scratchfile), "CMD")
self.text.insert(END, "checkstatus $? \"commit failed\"\n", "CMD")
self.text.insert(END, "rm %s\n" % msg_scratchfile, "CMD")
@@ -636,9 +639,11 @@ class AppGui(Frame):
self.text.insert(END, "OPENCM=${OPENCM:-cm}\n", "CMD")
self.text.insert(END, "export OPENCM\n", "CMD")
+ self.text.insert(END, "TMPDIR=${TMPDIR:-/tmp}\n", "CMD")
+ self.text.insert(END, "sd=$(mktemp -d ${TMPDIR}/scratchme.XXXXXX)\n", "CMD")
self.text.insert(END, "\n")
- self.text.insert(END, "function checkstatus()\n");
+ self.text.insert(END, "checkstatus()\n");
self.text.insert(END, "{\n");
self.text.insert(END, " if [ $1 -ne 0 ]\n");
self.text.insert(END, " then\n");
@@ -647,7 +652,7 @@ class AppGui(Frame):
self.text.insert(END, " fi\n");
self.text.insert(END, "}\n");
self.text.insert(END, "\n")
- self.text.insert(END, "function process_cvsignore()\n");
+ self.text.insert(END, "process_cvsignore()\n");
self.text.insert(END, "{\n");
self.text.insert(END, " echo CONVERTING .cvsignore: $1 '->' $2\n");
self.text.insert(END, " sed 's/^/exclude /' $1 > $2\n");
@@ -660,7 +665,7 @@ class AppGui(Frame):
self.text.insert(END, "checkstatus $? \"create project failed\"\n", "CMD");
self.text.insert(END, "rm -rf %s\n" % scratch_dir, "CMD")
- self.text.insert(END, "mkdir %s\n" % scratch_dir, "CMD")
+ self.text.insert(END, "mkdir -p %s\n" % scratch_dir, "CMD")
self.text.insert(END, "\n")
self.text.insert(END, "# Check out empty project so we have something to work with\n", "COMMENT")
self.text.insert(END, "(cd %s;${OPENCM} checkout %s)\n" % (scratch_dir, self.petName.get()), "CMD")

View File

@ -0,0 +1,34 @@
$OpenBSD: patch-base_zlib_gzio_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/zlib/gzio.c.orig Mon Jul 22 01:37:42 2002
+++ base/zlib/gzio.c Tue Aug 27 12:25:27 2002
@@ -681,6 +681,7 @@ z_off_t ZEXPORT gzseek (file, offset, wh
/* At this point, offset is the number of zero bytes to write. */
if (s->inbuf == Z_NULL) {
s->inbuf = (Byte*)ALLOC(Z_BUFSIZE); /* for seeking */
+ if (s->inbuf == Z_NULL) return -1L;
zmemzero(s->inbuf, Z_BUFSIZE);
}
while (offset > 0) {
@@ -723,6 +724,7 @@ z_off_t ZEXPORT gzseek (file, offset, wh
if (offset != 0 && s->outbuf == Z_NULL) {
s->outbuf = (Byte*)ALLOC(Z_BUFSIZE);
+ if (s->outbuf == Z_NULL) return -1L;
}
while (offset > 0) {
int size = Z_BUFSIZE;
@@ -862,12 +864,13 @@ const char* ZEXPORT gzerror (file, errn
*errnum = s->z_err;
if (*errnum == Z_OK) return (const char*)"";
- m = (char*)(*errnum == Z_ERRNO ? zstrerror(errno) : s->stream.msg);
+ m = (char*)(*errnum == Z_ERRNO ? zstrerror(errno) : s->stream.msg);
if (m == NULL || *m == '\0') m = (char*)ERR_MSG(s->z_err);
TRYFREE(s->msg);
s->msg = (char*)ALLOC(strlen(s->path) + strlen(m) + 3);
+ if (s->msg == Z_NULL) return (const char*)ERR_MSG(Z_MEM_ERROR);
strcpy(s->msg, s->path);
strcat(s->msg, ": ");
strcat(s->msg, m);

View File

@ -0,0 +1,12 @@
$OpenBSD: patch-base_zlib_zutil_c,v 1.1 2002/08/27 17:43:14 todd Exp $
--- base/zlib/zutil.c.orig Mon Jul 22 01:37:42 2002
+++ base/zlib/zutil.c Tue Aug 27 12:25:27 2002
@@ -211,6 +211,8 @@ voidpf zcalloc (opaque, items, size)
unsigned size;
{
if (opaque) items += size - size; /* make compiler happy */
+ if (items * size == 0)
+ return (NULL);
return (voidpf)calloc(items, size);
}
--- base/src/common/SDR.c.orig Mon Jul 29 22:48:31 2002
+++ base/src/common/SDR.c Tue Aug 27 12:27:10 2002
@@ -82,8 +82,8 @@ struct serializer {
void (*w_u16)(const char *, SDR_stream *, unsigned short);
unsigned short (*r_u16)(const char *, SDR_stream *);
- void (*w_u32)(const char *, SDR_stream *, unsigned long);
- unsigned long (*r_u32)(const char *, SDR_stream *);
+ void (*w_u32)(const char *, SDR_stream *, u_int32_t);
+ u_int32_t (*r_u32)(const char *, SDR_stream *);
void (*w_u64)(const char *, SDR_stream *,
oc_uint64_t);
@@ -92,8 +92,8 @@ struct serializer {
void (*w_buffer)(const char *elem, SDR_stream *, const Buffer*);
Buffer * (*r_buffer)(const char *elem, SDR_stream *, ocmoff_t len);
- void (*w_bytes)(const char *, SDR_stream *, unsigned long len, const void *);
- void * (*r_bytes)(const char *, SDR_stream *, unsigned long len);
+ void (*w_bytes)(const char *, SDR_stream *, u_int32_t len, const void *);
+ void * (*r_bytes)(const char *, SDR_stream *, u_int32_t len);
void (*w_string)(const char *, SDR_stream *, const char *);
char * (*r_string)(const char *, SDR_stream *);
@@ -568,8 +568,8 @@ stream_ungetc(SDR_stream *strm, int c)
size_t
stream_vprintf(SDR_stream *s, const char *fmt, va_list ap)
{
- unsigned long len;
- unsigned long width = 0;
+ u_int32_t len;
+ u_int32_t width = 0;
OC_bool sign;
OC_bool rightAdjust;
char fillchar;
@@ -584,7 +584,7 @@ stream_vprintf(SDR_stream *s, const char
continue;
}
/* largest thing we might convert fits in 20 digits (unsigned long
* long as decimal */
pend = &buf[20];
@@ -647,7 +647,7 @@ stream_vprintf(SDR_stream *s, const char
case 'd':
{
long l;
- unsigned long ul;
+ u_int32_t ul;
l = va_arg(ap, long);
@@ -661,7 +661,7 @@ stream_vprintf(SDR_stream *s, const char
ul = (l < 0) ? (unsigned) -l : (unsigned) l;
if (l == LONG_MIN)
- ul = ((unsigned long) LONG_MAX) + 1ul;
+ ul = ((u_int32_t) LONG_MAX) + 1ul;
while(ul) {
*(--p) = '0' + (ul % 10);
@@ -675,9 +675,9 @@ stream_vprintf(SDR_stream *s, const char
}
case 'u':
{
- unsigned long ul;
+ u_int32_t ul;
- ul = va_arg(ap, unsigned long);
+ ul = va_arg(ap, u_int32_t);
if (ul == 0) {
*(--p) = '0';
@@ -692,11 +692,11 @@ stream_vprintf(SDR_stream *s, const char
}
case 'x':
{
- unsigned long ul;
+ u_int32_t ul;
char *hexout = "0123456789abcdef";
- ul = va_arg(ap, unsigned long);
+ ul = va_arg(ap, u_int32_t);
if (ul == 0) {
*(--p) = '0';
@@ -826,7 +826,7 @@ stream_scanf(SDR_stream *s, const char *
case 'u':
case 'U':
{
- unsigned long ull = 0;
+ u_int32_t ull = 0;
do {
c = stream_getc(s);
@@ -852,10 +852,10 @@ stream_scanf(SDR_stream *s, const char *
--input_count;
if (*fmt == 'u') {
- unsigned long *ulp;
+ u_int32_t *ulp;
- ulp = va_arg(ap, unsigned long *);
- *ulp = (unsigned long) ull;
+ ulp = va_arg(ap, u_int32_t *);
+ *ulp = (u_int32_t) ull;
assert(ull <= ULONG_MAX);
}
else {
@@ -869,10 +869,10 @@ stream_scanf(SDR_stream *s, const char *
}
case 'x':
{
- unsigned long ul = 0;
- unsigned long *ulp;
+ u_int32_t ul = 0;
+ u_int32_t *ulp;
- ulp = va_arg(ap, unsigned long *);
+ ulp = va_arg(ap, u_int32_t *);
do {
c = stream_getc(s);
@@ -1345,13 +1345,13 @@ sdr_r_u16(const char *elem, SDR_stream *
}
void
-sdr_w_u32(const char *elem, SDR_stream *strm, unsigned long u)
+sdr_w_u32(const char *elem, SDR_stream *strm, u_int32_t u)
{
assert(sermodes[strm->format].w_u32);
sermodes[strm->format].w_u32(elem, strm, u);
}
-unsigned long
+u_int32_t
sdr_r_u32(const char *elem, SDR_stream *strm)
{
assert(sermodes[strm->format].r_u32);
@@ -1387,14 +1387,14 @@ sdr_r_buffer(const char *elem, SDR_strea
}
void
-sdr_w_bytes(const char *elem, SDR_stream *strm, unsigned long len, const void *v)
+sdr_w_bytes(const char *elem, SDR_stream *strm, u_int32_t len, const void *v)
{
assert(sermodes[strm->format].w_bytes);
sermodes[strm->format].w_bytes(elem, strm, len, v);
}
void *
-sdr_r_bytes(const char *elem, SDR_stream *strm, unsigned long len)
+sdr_r_bytes(const char *elem, SDR_stream *strm, u_int32_t len)
{
assert(sermodes[strm->format].r_bytes);
return sermodes[strm->format].r_bytes(elem, strm, len);
@@ -1496,7 +1496,7 @@ bin_r_u16(const char *elem, SDR_stream *
u = 0;
do {
- unsigned long bu;
+ u_int32_t bu;
i--;
u = u << 8;
@@ -1508,7 +1508,7 @@ bin_r_u16(const char *elem, SDR_stream *
}
static void
-bin_w_u32(const char *elem, SDR_stream *strm, unsigned long u)
+bin_w_u32(const char *elem, SDR_stream *strm, u_int32_t u)
{
int i;
unsigned char bytes[sizeof(u)];
@@ -1522,11 +1522,11 @@ bin_w_u32(const char *elem, SDR_stream *
THROW(ExTruncated, "Serialization write error");
}
-static unsigned long
+static u_int32_t
bin_r_u32(const char *elem, SDR_stream *strm)
{
int i;
- unsigned long u;
+ u_int32_t u;
unsigned char bytes[sizeof(u)];
if (stream_read(strm, bytes, sizeof(u)) < sizeof(u))
@@ -1536,7 +1536,7 @@ bin_r_u32(const char *elem, SDR_stream *
u = 0;
do {
- unsigned long bu;
+ u_int32_t bu;
i--;
u = u << 8;
@@ -1589,7 +1589,7 @@ bin_r_u64(const char *elem, SDR_stream *
/* Note that these do NOT read/write the actual length! */
static void
-bin_w_bytes(const char *elem, SDR_stream *strm, unsigned long len,
+bin_w_bytes(const char *elem, SDR_stream *strm, u_int32_t len,
const void *v)
{
const char *s = (const char *) v;
@@ -1599,7 +1599,7 @@ bin_w_bytes(const char *elem, SDR_stream
}
static void *
-bin_r_bytes(const char *elem, SDR_stream *strm, unsigned long len)
+bin_r_bytes(const char *elem, SDR_stream *strm, u_int32_t len)
{
char * s = (char *) GC_MALLOC_ATOMIC(sizeof(char) * (len+1));
s[len] = 0;
@@ -1935,7 +1935,7 @@ texty_w_u16(const char *elem, SDR_stream
}
static void
-texty_w_u32(const char *elem, SDR_stream *strm, unsigned long num)
+texty_w_u32(const char *elem, SDR_stream *strm, u_int32_t num)
{
texty_do_indent(strm);
stream_printf(strm, "%s I %u\n", elem, num);
@@ -1955,7 +1955,7 @@ texty_r_u16(const char *elem, SDR_stream
return fld->value;
}
-static unsigned long
+static u_int32_t
texty_r_u32(const char *elem, SDR_stream *strm)
{
texty_field *fld = texty_get_field(elem, 'I', strm);
@@ -1978,7 +1978,7 @@ texty_r_u64(const char *elem, SDR_stream
static void
texty_w_bytestring(const char *elem, SDR_stream *strm, const char ty,
- unsigned long len, const void *vp)
+ u_int32_t len, const void *vp)
{
texty_do_indent(strm);
@@ -2019,14 +2019,14 @@ texty_r_buffer(const char *elem, SDR_str
}
static void
-texty_w_bytes(const char *elem, SDR_stream *strm, unsigned long len,
+texty_w_bytes(const char *elem, SDR_stream *strm, u_int32_t len,
const void *obj)
{
texty_w_bytestring(elem, strm, 'B', len, obj);
}
static void *
-texty_r_bytes(const char *elem, SDR_stream *strm, unsigned long len)
+texty_r_bytes(const char *elem, SDR_stream *strm, u_int32_t len)
{
texty_field *fld = texty_get_field(elem, 'B', strm);
return fld->rep;
@@ -2169,7 +2169,7 @@ encodeString(const void *vp, ocmoff_t le
static void
dtexty_w_bytestring(const char *elem, SDR_stream *strm, const char ty,
- unsigned long len, const void *vp)
+ u_int32_t len, const void *vp)
{
ocmoff_t elen = len; /* encoded length */
const void *evp = vp; /* encoded string */
@@ -2334,7 +2334,7 @@ dtexty_get_field(const char *name, char
#if 0
static void
dtexty_w_bytestring(const char *elem, SDR_stream *strm, const char ty,
- unsigned long len, const void *vp)
+ u_int32_t len, const void *vp)
{
texty_do_indent(strm);
@@ -2415,14 +2415,14 @@ dtexty_r_buffer(const char *elem, SDR_st
dtexty_w_bytestring and dtexty_get_field. Yuck.
*/
static void
-dtexty_w_bytes(const char *elem, SDR_stream *strm, unsigned long len,
+dtexty_w_bytes(const char *elem, SDR_stream *strm, u_int32_t len,
const void *s)
{
dtexty_w_bytestring(elem, strm, 'B', len, s);
}
static void *
-dtexty_r_bytes(const char *elem, SDR_stream *strm, unsigned long len)
+dtexty_r_bytes(const char *elem, SDR_stream *strm, u_int32_t len)
{
texty_field *fld = dtexty_get_field(elem, 'B', strm);
return fld->rep;

View File

@ -0,0 +1,25 @@
$OpenBSD: patch-base_src_common_SDR_h,v 1.1 2002/08/27 17:43:14 todd Exp $
@@ -584,7 +584,7 @@ stream_vprintf(SDR_stream *s, const char
continue;
}
- /* largest thing we might convert fits in 20 digits (unsigned long
+ /* largest thing we might convert fits in 20 digits (u_int32_t
* long as decimal */
pend = &buf[20];
--- base/src/common/util.c.orig Mon Aug 5 16:03:07 2002
+++ base/src/common/util.c Tue Aug 27 12:25:27 2002
@@ -179,8 +179,8 @@ nmequal(const char *s1, const char *s2)
size_t
xprintf(const char *fmt, ...)
{
- unsigned long len;
- unsigned long width = 0;
+ u_int32_t len;
+ u_int32_t width = 0;
OC_bool sign;
OC_bool rightAdjust;
char fillchar;
@@ -199,7 +199,7 @@ xprintf(const char *fmt, ...)
continue;
}
/* largest thing we might convert fits in 20 digits (unsigned long
* long as decimal */
pend = &buf[20];
@@ -263,7 +263,7 @@ xprintf(const char *fmt, ...)
case 'd':
{
long l;
- unsigned long ul;
+ u_int32_t ul;
l = va_arg(ap, long);
@@ -277,7 +277,7 @@ xprintf(const char *fmt, ...)
ul = (l < 0) ? (unsigned) -l : (unsigned) l;
if (l == LONG_MIN)
- ul = ((unsigned long) LONG_MAX) + 1ul;
+ ul = ((u_int32_t) LONG_MAX) + 1ul;
while(ul) {
*(--p) = '0' + (ul % 10);
@@ -288,9 +288,9 @@ xprintf(const char *fmt, ...)
}
case 'u':
{
- unsigned long ul;
+ u_int32_t ul;
- ul = va_arg(ap, unsigned long);
+ ul = va_arg(ap, u_int32_t);
if (ul == 0) {
*(--p) = '0';
@@ -305,10 +305,10 @@ xprintf(const char *fmt, ...)
}
case 'x':
{
- unsigned long ul;
+ u_int32_t ul;
static char *hex_digits = "0123456789abcdef";
- ul = va_arg(ap, unsigned long);
+ ul = va_arg(ap, u_int32_t);
if (ul == 0) {
*(--p) = '0';

View File

@ -1,6 +1,7 @@
@@ -199,7 +199,7 @@ xprintf(const char *fmt, ...)
continue;
}
- /* largest thing we might convert fits in 20 digits (unsigned long
+ /* largest thing we might convert fits in 20 digits (u_int32_t
* long as decimal */
pend = &buf[20];